@@ -18,6 +18,8 @@
 import os
 import sys
 
+from pathlib import Path
+
 
 def get_config_home_directory():
     if sys.platform == "win32":
@@ -25,16 +27,12 @@ def get_config_home_directory():
     return get_config_home_directory_xdg()
 
 def get_config_home_directory_windows():
-    directory = os.path.expanduser("~")
-    directory = os.environ.get("APPDATA", directory)
-    directory = os.path.join(directory, "NFO Viewer")
-    return os.path.abspath(directory)
+    directory = os.environ.get("APPDATA", Path.home())
+    return Path(directory) / "NFO Viewer"
 
 def get_config_home_directory_xdg():
-    directory = os.path.join(os.path.expanduser("~"), ".config")
-    directory = os.environ.get("XDG_CONFIG_HOME", directory)
-    directory = os.path.join(directory, "nfoview")
-    return os.path.abspath(directory)
+    directory = os.environ.get("XDG_CONFIG_HOME", Path.home() / ".config")
+    return Path(directory) / "nfoview"
 
 def get_data_directory():
     if hasattr(sys, "frozen"):
@@ -42,15 +40,10 @@ def get_data_directory():
     return get_data_directory_source()
 
 def get_data_directory_frozen():
-    directory = os.path.dirname(sys.argv[0])
-    directory = os.path.join(directory, "share", "nfoview")
-    return os.path.abspath(directory)
+    return Path(sys.argv[0]).parent / "share" / "nfoview"
 
 def get_data_directory_source():
-    directory = os.path.dirname(os.path.abspath(__file__))
-    directory = os.path.abspath(os.path.join(directory, ".."))
-    directory = os.path.join(directory, "data")
-    return os.path.abspath(directory)
+    return Path(__file__).parent.parent / "data"
 
 def get_locale_directory():
     if hasattr(sys, "frozen"):
@@ -58,16 +51,11 @@ def get_locale_directory():
     return get_locale_directory_source()
 
 def get_locale_directory_frozen():
-    directory = os.path.dirname(sys.argv[0])
-    directory = os.path.join(directory, "share", "locale")
-    return os.path.abspath(directory)
+    return Path(sys.argv[0]).parent / "share" / "locale"
 
 def get_locale_directory_source():
-    directory = os.path.dirname(os.path.abspath(__file__))
-    directory = os.path.abspath(os.path.join(directory, ".."))
-    directory = os.path.join(directory, "locale")
-    return os.path.abspath(directory)
+    return Path(__file__).parent.parent / "locale"
 
-CONFIG_HOME_DIR = get_config_home_directory()
-DATA_DIR = '/usr/share/nfoview'
-LOCALE_DIR = '/usr/share/locale'
+CONFIG_HOME_DIR = get_config_home_directory().resolve()
+DATA_DIR = Path('/usr/share/nfoview')
+LOCALE_DIR = Path('/usr/share/locale')
